using System;
using System.Diagnostics;
using System.Globalization;
using System.Text;
using System.Windows.Forms;
using JTLeigh.Tools.Development.CopySourceAsHtml.Properties;

namespace JTLeigh.Tools.Development.CopySourceAsHtml
{

    public sealed class CopierPreferencesDialog : Form
    {

		private TabControl tabs;

        private TabPage tabFileStyle;
        private Label fileStyleLabel;
        private TextBox fileStyleText;

        private TabPage tabLineStyle;
        private Label lineStyleLabel;
        private TextBox lineStyleText;

        private TabPage tabBlockStyle;
        private Label blockStyleLabel;
        private TextBox blockStyleText;

        private TabPage tabAddIn;
        private CheckBox addCopyContextMenuCheck;
        private CheckBox addCopyNowContextMenuCheck;

        private TabPage tabAbout;
        private Label versionLabel;
        private Label copyrightLabel;
        private TextBox licenseText;
        private LinkLabel visitWebSiteLabel;

        private Button okButton;
        private Button cancelButton;

        private System.ComponentModel.Container components = null;
        private CheckBox addCopyNowEditMenuCheck;
        private CheckBox addCopyEditMenuCheck;
        private Label copyLabel;
		private CheckBox saveScenariosCheck;
		private CheckBox addSaveNowFileMenuCheck;
		private CheckBox addSaveFileMenuCheck;
		private CheckBox restartVirtualMachineAdditionsCheck;
		private LinkLabel previewCopiedHtmlLabel;
		private TabPage tabGeneral;
		private ComboBox pathCombo;
		private CheckBox copyFileNameCheck;
		private Label adjustmentPercentLabel;
		private NumericUpDown adjustmentUpDown;
		private CheckBox alternateBackgroundColorsCheck;
		private CheckBox removeIndentationCheck;
		private TextBox tabSizeText;
		private TextBox fontListText;
		private TextBox fontSizeText;
		private TextBox numberLinesFromText;
		private CheckBox numberLinesCheck;
		private CheckBox wrapWordsCheck;
		private CheckBox overrideTabSizeCheck;
		private CheckBox overrideFontSizeCheck;
		private CheckBox overrideFontListCheck;
		private TabPage tabOutput;
		private CheckBox stripLineBreaksCheck;
		private CheckBox embedStylesCheck;
		private TabPage tabFileNameStyle;
		private Label fileNameStyleLabel;
		private TextBox fileNameStyleText;
		private TabPage tabLineNumberStyle;
		private Label lineNumberStyleLabel;
		private TextBox lineNumberStyleText;
        private Label copyNowLabel;

        public CopierPreferencesDialog()
        {

            InitializeComponent();

			previewCopiedHtmlLabel.Links.Add(0, previewCopiedHtmlLabel.Text.Length, "about:preview");
			previewCopiedHtmlLabel.TabStop = false;

            visitWebSiteLabel.Links.Add(0, visitWebSiteLabel.Text.Length, "http://www.jtleigh.com/CopySourceAsHtml/");
			visitWebSiteLabel.TabStop = false;

            numberLinesCheck.Checked = Settings.Default.NumberLines;
            numberLinesFromText.Text = Settings.Default.NumberLinesFrom.ToString(NumberFormatInfo.InvariantInfo);
            numberLinesFromText.Enabled = Settings.Default.NumberLines;
            wrapWordsCheck.Checked = Settings.Default.WrapWords;
            embedStylesCheck.Checked = Settings.Default.EmbedStyles;
            stripLineBreaksCheck.Checked = Settings.Default.StripLineBreaks;
            removeIndentationCheck.Checked = Settings.Default.RemoveIndentation;
            overrideTabSizeCheck.Checked = Settings.Default.OverrideTabSize;
            tabSizeText.Text = Settings.Default.TabSize.ToString(NumberFormatInfo.InvariantInfo);
            tabSizeText.Enabled = Settings.Default.OverrideTabSize;
            overrideFontListCheck.Checked = Settings.Default.OverrideFontList;
            fontListText.Text = GetCleanFontList(Settings.Default.FontList);
            fontListText.Enabled = Settings.Default.OverrideFontList;
            overrideFontSizeCheck.Checked = Settings.Default.OverrideFontSize;
			fontSizeText.Text = Settings.Default.FontSize.ToString(NumberFormatInfo.InvariantInfo);
            fontSizeText.Enabled = Settings.Default.OverrideFontSize;
			alternateBackgroundColorsCheck.Checked = Settings.Default.AlternateBackgroundColors;
			adjustmentUpDown.Value = (decimal)(Settings.Default.AlternateBackgroundColorAdjustment * 100);
			adjustmentUpDown.Enabled = Settings.Default.AlternateBackgroundColors;
			copyFileNameCheck.Checked = Settings.Default.CopyFileName;
			// TODO: copyFileNamePath...
			fileStyleText.Text = GetFriendlyStyleList(Settings.Default.FileStyle);
			fileNameStyleText.Text = GetFriendlyStyleList(Settings.Default.FileNameStyle);
			lineStyleText.Text = GetFriendlyStyleList(Settings.Default.LineStyle);
			lineNumberStyleText.Text = GetFriendlyStyleList(Settings.Default.LineNumberStyle);
			blockStyleText.Text = GetFriendlyStyleList(Settings.Default.BlockStyle);
			addSaveFileMenuCheck.Checked = Settings.Default.AddSaveFileMenu;
            addCopyEditMenuCheck.Checked = Settings.Default.AddCopyEditMenu;
            addCopyContextMenuCheck.Checked = Settings.Default.AddCopyContextMenu;
			addSaveNowFileMenuCheck.Checked = Settings.Default.AddSaveNowFileMenu;
			addCopyNowEditMenuCheck.Checked = Settings.Default.AddCopyNowEditMenu;
			addCopyNowContextMenuCheck.Checked = Settings.Default.AddCopyNowContextMenu;
			restartVirtualMachineAdditionsCheck.Checked = Settings.Default.RestartVirtualMachineAdditions;
			saveScenariosCheck.Checked = Settings.Default.SaveScenarios;
		}

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                if (components != null)
                {
                    components.Dispose();
                }
            }
            base.Dispose(disposing);
        }

        #region Windows Form Designer generated code
        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
			System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(CopierPreferencesDialog));
			this.okButton = new System.Windows.Forms.Button();
			this.cancelButton = new System.Windows.Forms.Button();
			this.tabs = new System.Windows.Forms.TabControl();
			this.tabGeneral = new System.Windows.Forms.TabPage();
			this.pathCombo = new System.Windows.Forms.ComboBox();
			this.copyFileNameCheck = new System.Windows.Forms.CheckBox();
			this.adjustmentPercentLabel = new System.Windows.Forms.Label();
			this.adjustmentUpDown = new System.Windows.Forms.NumericUpDown();
			this.alternateBackgroundColorsCheck = new System.Windows.Forms.CheckBox();
			this.removeIndentationCheck = new System.Windows.Forms.CheckBox();
			this.tabSizeText = new System.Windows.Forms.TextBox();
			this.fontListText = new System.Windows.Forms.TextBox();
			this.fontSizeText = new System.Windows.Forms.TextBox();
			this.numberLinesFromText = new System.Windows.Forms.TextBox();
			this.numberLinesCheck = new System.Windows.Forms.CheckBox();
			this.wrapWordsCheck = new System.Windows.Forms.CheckBox();
			this.overrideTabSizeCheck = new System.Windows.Forms.CheckBox();
			this.overrideFontSizeCheck = new System.Windows.Forms.CheckBox();
			this.overrideFontListCheck = new System.Windows.Forms.CheckBox();
			this.tabFileStyle = new System.Windows.Forms.TabPage();
			this.fileStyleLabel = new System.Windows.Forms.Label();
			this.fileStyleText = new System.Windows.Forms.TextBox();
			this.tabFileNameStyle = new System.Windows.Forms.TabPage();
			this.fileNameStyleLabel = new System.Windows.Forms.Label();
			this.fileNameStyleText = new System.Windows.Forms.TextBox();
			this.tabLineStyle = new System.Windows.Forms.TabPage();
			this.lineStyleLabel = new System.Windows.Forms.Label();
			this.lineStyleText = new System.Windows.Forms.TextBox();
			this.tabLineNumberStyle = new System.Windows.Forms.TabPage();
			this.lineNumberStyleLabel = new System.Windows.Forms.Label();
			this.lineNumberStyleText = new System.Windows.Forms.TextBox();
			this.tabBlockStyle = new System.Windows.Forms.TabPage();
			this.blockStyleLabel = new System.Windows.Forms.Label();
			this.blockStyleText = new System.Windows.Forms.TextBox();
			this.tabOutput = new System.Windows.Forms.TabPage();
			this.stripLineBreaksCheck = new System.Windows.Forms.CheckBox();
			this.embedStylesCheck = new System.Windows.Forms.CheckBox();
			this.tabAddIn = new System.Windows.Forms.TabPage();
			this.restartVirtualMachineAdditionsCheck = new System.Windows.Forms.CheckBox();
			this.addSaveNowFileMenuCheck = new System.Windows.Forms.CheckBox();
			this.addSaveFileMenuCheck = new System.Windows.Forms.CheckBox();
			this.saveScenariosCheck = new System.Windows.Forms.CheckBox();
			this.copyNowLabel = new System.Windows.Forms.Label();
			this.copyLabel = new System.Windows.Forms.Label();
			this.addCopyNowEditMenuCheck = new System.Windows.Forms.CheckBox();
			this.addCopyEditMenuCheck = new System.Windows.Forms.CheckBox();
			this.addCopyNowContextMenuCheck = new System.Windows.Forms.CheckBox();
			this.addCopyContextMenuCheck = new System.Windows.Forms.CheckBox();
			this.tabAbout = new System.Windows.Forms.TabPage();
			this.visitWebSiteLabel = new System.Windows.Forms.LinkLabel();
			this.copyrightLabel = new System.Windows.Forms.Label();
			this.versionLabel = new System.Windows.Forms.Label();
			this.licenseText = new System.Windows.Forms.TextBox();
			this.previewCopiedHtmlLabel = new System.Windows.Forms.LinkLabel();
			this.tabs.SuspendLayout();
			this.tabGeneral.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.adjustmentUpDown)).BeginInit();
			this.tabFileStyle.SuspendLayout();
			this.tabFileNameStyle.SuspendLayout();
			this.tabLineStyle.SuspendLayout();
			this.tabLineNumberStyle.SuspendLayout();
			this.tabBlockStyle.SuspendLayout();
			this.tabOutput.SuspendLayout();
			this.tabAddIn.SuspendLayout();
			this.tabAbout.SuspendLayout();
			this.SuspendLayout();
			// 
			// okButton
			// 
			this.okButton.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
			this.okButton.DialogResult = System.Windows.Forms.DialogResult.OK;
			this.okButton.Location = new System.Drawing.Point(432, 244);
			this.okButton.Name = "okButton";
			this.okButton.Size = new System.Drawing.Size(75, 23);
			this.okButton.TabIndex = 1;
			this.okButton.Text = "OK";
			this.okButton.Click += new System.EventHandler(this.okButton_Click);
			// 
			// cancelButton
			// 
			this.cancelButton.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
			this.cancelButton.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.cancelButton.Location = new System.Drawing.Point(512, 244);
			this.cancelButton.Name = "cancelButton";
			this.cancelButton.Size = new System.Drawing.Size(75, 23);
			this.cancelButton.TabIndex = 2;
			this.cancelButton.Text = "Cancel";
			// 
			// tabs
			// 
			this.tabs.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
						| System.Windows.Forms.AnchorStyles.Left)
						| System.Windows.Forms.AnchorStyles.Right)));
			this.tabs.Controls.Add(this.tabGeneral);
			this.tabs.Controls.Add(this.tabFileStyle);
			this.tabs.Controls.Add(this.tabFileNameStyle);
			this.tabs.Controls.Add(this.tabLineStyle);
			this.tabs.Controls.Add(this.tabLineNumberStyle);
			this.tabs.Controls.Add(this.tabBlockStyle);
			this.tabs.Controls.Add(this.tabOutput);
			this.tabs.Controls.Add(this.tabAddIn);
			this.tabs.Controls.Add(this.tabAbout);
			this.tabs.Location = new System.Drawing.Point(8, 8);
			this.tabs.Name = "tabs";
			this.tabs.SelectedIndex = 0;
			this.tabs.Size = new System.Drawing.Size(579, 230);
			this.tabs.TabIndex = 0;
			// 
			// tabGeneral
			// 
			this.tabGeneral.Controls.Add(this.pathCombo);
			this.tabGeneral.Controls.Add(this.copyFileNameCheck);
			this.tabGeneral.Controls.Add(this.adjustmentPercentLabel);
			this.tabGeneral.Controls.Add(this.adjustmentUpDown);
			this.tabGeneral.Controls.Add(this.alternateBackgroundColorsCheck);
			this.tabGeneral.Controls.Add(this.removeIndentationCheck);
			this.tabGeneral.Controls.Add(this.tabSizeText);
			this.tabGeneral.Controls.Add(this.fontListText);
			this.tabGeneral.Controls.Add(this.fontSizeText);
			this.tabGeneral.Controls.Add(this.numberLinesFromText);
			this.tabGeneral.Controls.Add(this.numberLinesCheck);
			this.tabGeneral.Controls.Add(this.wrapWordsCheck);
			this.tabGeneral.Controls.Add(this.overrideTabSizeCheck);
			this.tabGeneral.Controls.Add(this.overrideFontSizeCheck);
			this.tabGeneral.Controls.Add(this.overrideFontListCheck);
			this.tabGeneral.Location = new System.Drawing.Point(4, 22);
			this.tabGeneral.Name = "tabGeneral";
			this.tabGeneral.Size = new System.Drawing.Size(571, 204);
			this.tabGeneral.TabIndex = 0;
			this.tabGeneral.Text = "General";
			this.tabGeneral.UseVisualStyleBackColor = true;
			// 
			// pathCombo
			// 
			this.pathCombo.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.pathCombo.FormattingEnabled = true;
			this.pathCombo.Items.AddRange(new object[] {
            "without path",
            "with path relative to project",
            "with path relative to solution",
            "with full path"});
			this.pathCombo.Location = new System.Drawing.Point(151, 175);
			this.pathCombo.Name = "pathCombo";
			this.pathCombo.Size = new System.Drawing.Size(182, 21);
			this.pathCombo.TabIndex = 14;
			this.pathCombo.Visible = false;
			// 
			// copyFileNameCheck
			// 
			this.copyFileNameCheck.AutoSize = true;
			this.copyFileNameCheck.Location = new System.Drawing.Point(8, 177);
			this.copyFileNameCheck.Name = "copyFileNameCheck";
			this.copyFileNameCheck.Size = new System.Drawing.Size(92, 17);
			this.copyFileNameCheck.TabIndex = 13;
			this.copyFileNameCheck.Text = "Copy fi&lename";
			this.copyFileNameCheck.UseVisualStyleBackColor = true;
			this.copyFileNameCheck.CheckedChanged += new System.EventHandler(this.copyFileNameCheck_CheckedChanged);
			// 
			// adjustmentPercentLabel
			// 
			this.adjustmentPercentLabel.AutoSize = true;
			this.adjustmentPercentLabel.Location = new System.Drawing.Point(202, 154);
			this.adjustmentPercentLabel.Name = "adjustmentPercentLabel";
			this.adjustmentPercentLabel.Size = new System.Drawing.Size(133, 13);
			this.adjustmentPercentLabel.TabIndex = 12;
			this.adjustmentPercentLabel.Text = "% (+ for lighter, - for darker)";
			// 
			// adjustmentUpDown
			// 
			this.adjustmentUpDown.Location = new System.Drawing.Point(151, 151);
			this.adjustmentUpDown.Maximum = new decimal(new int[] {
            30,
            0,
            0,
            0});
			this.adjustmentUpDown.Minimum = new decimal(new int[] {
            30,
            0,
            0,
            -2147483648});
			this.adjustmentUpDown.Name = "adjustmentUpDown";
			this.adjustmentUpDown.Size = new System.Drawing.Size(48, 20);
			this.adjustmentUpDown.TabIndex = 11;
			// 
			// alternateBackgroundColorsCheck
			// 
			this.alternateBackgroundColorsCheck.AutoSize = true;
			this.alternateBackgroundColorsCheck.Location = new System.Drawing.Point(8, 152);
			this.alternateBackgroundColorsCheck.Name = "alternateBackgroundColorsCheck";
			this.alternateBackgroundColorsCheck.Size = new System.Drawing.Size(131, 17);
			this.alternateBackgroundColorsCheck.TabIndex = 10;
			this.alternateBackgroundColorsCheck.Text = "&Alternate background:";
			this.alternateBackgroundColorsCheck.UseVisualStyleBackColor = true;
			this.alternateBackgroundColorsCheck.CheckedChanged += new System.EventHandler(this.alternateBackgroundColorsCheck_CheckedChanged);
			// 
			// removeIndentationCheck
			// 
			this.removeIndentationCheck.BackColor = System.Drawing.SystemColors.Control;
			this.removeIndentationCheck.Location = new System.Drawing.Point(8, 56);
			this.removeIndentationCheck.Name = "removeIndentationCheck";
			this.removeIndentationCheck.Size = new System.Drawing.Size(141, 17);
			this.removeIndentationCheck.TabIndex = 3;
			this.removeIndentationCheck.Text = "Remove line &indentation";
			this.removeIndentationCheck.UseVisualStyleBackColor = false;
			// 
			// tabSizeText
			// 
			this.tabSizeText.Location = new System.Drawing.Point(151, 80);
			this.tabSizeText.Name = "tabSizeText";
			this.tabSizeText.Size = new System.Drawing.Size(24, 20);
			this.tabSizeText.TabIndex = 5;
			// 
			// fontListText
			// 
			this.fontListText.Location = new System.Drawing.Point(151, 104);
			this.fontListText.Name = "fontListText";
			this.fontListText.Size = new System.Drawing.Size(417, 20);
			this.fontListText.TabIndex = 7;
			// 
			// fontSizeText
			// 
			this.fontSizeText.Location = new System.Drawing.Point(151, 128);
			this.fontSizeText.Name = "fontSizeText";
			this.fontSizeText.Size = new System.Drawing.Size(24, 20);
			this.fontSizeText.TabIndex = 9;
			// 
			// numberLinesFromText
			// 
			this.numberLinesFromText.Location = new System.Drawing.Point(151, 8);
			this.numberLinesFromText.Name = "numberLinesFromText";
			this.numberLinesFromText.Size = new System.Drawing.Size(48, 20);
			this.numberLinesFromText.TabIndex = 1;
			// 
			// numberLinesCheck
			// 
			this.numberLinesCheck.Location = new System.Drawing.Point(8, 8);
			this.numberLinesCheck.Name = "numberLinesCheck";
			this.numberLinesCheck.Size = new System.Drawing.Size(128, 17);
			this.numberLinesCheck.TabIndex = 0;
			this.numberLinesCheck.Text = "&Number lines from:";
			this.numberLinesCheck.CheckedChanged += new System.EventHandler(this.numberLinesCheck_CheckedChanged);
			// 
			// wrapWordsCheck
			// 
			this.wrapWordsCheck.BackColor = System.Drawing.SystemColors.Control;
			this.wrapWordsCheck.Location = new System.Drawing.Point(8, 32);
			this.wrapWordsCheck.Name = "wrapWordsCheck";
			this.wrapWordsCheck.Size = new System.Drawing.Size(88, 17);
			this.wrapWordsCheck.TabIndex = 2;
			this.wrapWordsCheck.Text = "&Wrap lines";
			this.wrapWordsCheck.UseVisualStyleBackColor = false;
			// 
			// overrideTabSizeCheck
			// 
			this.overrideTabSizeCheck.Location = new System.Drawing.Point(8, 80);
			this.overrideTabSizeCheck.Name = "overrideTabSizeCheck";
			this.overrideTabSizeCheck.Size = new System.Drawing.Size(120, 17);
			this.overrideTabSizeCheck.TabIndex = 4;
			this.overrideTabSizeCheck.Text = "Override &tab size:";
			this.overrideTabSizeCheck.CheckedChanged += new System.EventHandler(this.overrideTabSizeCheck_CheckedChanged);
			// 
			// overrideFontSizeCheck
			// 
			this.overrideFontSizeCheck.Location = new System.Drawing.Point(8, 128);
			this.overrideFontSizeCheck.Name = "overrideFontSizeCheck";
			this.overrideFontSizeCheck.Size = new System.Drawing.Size(120, 17);
			this.overrideFontSizeCheck.TabIndex = 8;
			this.overrideFontSizeCheck.Text = "Override font &size:";
			this.overrideFontSizeCheck.CheckedChanged += new System.EventHandler(this.overrideFontSizeCheck_CheckedChanged);
			// 
			// overrideFontListCheck
			// 
			this.overrideFontListCheck.Location = new System.Drawing.Point(8, 104);
			this.overrideFontListCheck.Name = "overrideFontListCheck";
			this.overrideFontListCheck.Size = new System.Drawing.Size(120, 17);
			this.overrideFontListCheck.TabIndex = 6;
			this.overrideFontListCheck.Text = "Override &font list:";
			this.overrideFontListCheck.CheckedChanged += new System.EventHandler(this.overrideFontListCheck_CheckedChanged);
			// 
			// tabFileStyle
			// 
			this.tabFileStyle.Controls.Add(this.fileStyleLabel);
			this.tabFileStyle.Controls.Add(this.fileStyleText);
			this.tabFileStyle.Location = new System.Drawing.Point(4, 22);
			this.tabFileStyle.Name = "tabFileStyle";
			this.tabFileStyle.Size = new System.Drawing.Size(571, 204);
			this.tabFileStyle.TabIndex = 1;
			this.tabFileStyle.Text = "File Style";
			this.tabFileStyle.UseVisualStyleBackColor = true;
			// 
			// fileStyleLabel
			// 
			this.fileStyleLabel.Location = new System.Drawing.Point(8, 8);
			this.fileStyleLabel.Name = "fileStyleLabel";
			this.fileStyleLabel.Size = new System.Drawing.Size(392, 16);
			this.fileStyleLabel.TabIndex = 1;
			this.fileStyleLabel.Text = "Additional CSS rules for the file\'s <div> tag:";
			// 
			// fileStyleText
			// 
			this.fileStyleText.AcceptsReturn = true;
			this.fileStyleText.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
						| System.Windows.Forms.AnchorStyles.Left)
						| System.Windows.Forms.AnchorStyles.Right)));
			this.fileStyleText.Location = new System.Drawing.Point(8, 24);
			this.fileStyleText.Multiline = true;
			this.fileStyleText.Name = "fileStyleText";
			this.fileStyleText.ScrollBars = System.Windows.Forms.ScrollBars.Vertical;
			this.fileStyleText.Size = new System.Drawing.Size(555, 174);
			this.fileStyleText.TabIndex = 13;
			// 
			// tabFileNameStyle
			// 
			this.tabFileNameStyle.Controls.Add(this.fileNameStyleLabel);
			this.tabFileNameStyle.Controls.Add(this.fileNameStyleText);
			this.tabFileNameStyle.Location = new System.Drawing.Point(4, 22);
			this.tabFileNameStyle.Name = "tabFileNameStyle";
			this.tabFileNameStyle.Padding = new System.Windows.Forms.Padding(3);
			this.tabFileNameStyle.Size = new System.Drawing.Size(571, 204);
			this.tabFileNameStyle.TabIndex = 7;
			this.tabFileNameStyle.Text = "Filename Style";
			this.tabFileNameStyle.UseVisualStyleBackColor = true;
			// 
			// fileNameStyleLabel
			// 
			this.fileNameStyleLabel.Location = new System.Drawing.Point(8, 8);
			this.fileNameStyleLabel.Name = "fileNameStyleLabel";
			this.fileNameStyleLabel.Size = new System.Drawing.Size(392, 16);
			this.fileNameStyleLabel.TabIndex = 15;
			this.fileNameStyleLabel.Text = "Additional CSS rules for the filename line\'s <p> or <pre> tag:";
			// 
			// fileNameStyleText
			// 
			this.fileNameStyleText.AcceptsReturn = true;
			this.fileNameStyleText.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
						| System.Windows.Forms.AnchorStyles.Left)
						| System.Windows.Forms.AnchorStyles.Right)));
			this.fileNameStyleText.Location = new System.Drawing.Point(8, 24);
			this.fileNameStyleText.Multiline = true;
			this.fileNameStyleText.Name = "fileNameStyleText";
			this.fileNameStyleText.ScrollBars = System.Windows.Forms.ScrollBars.Vertical;
			this.fileNameStyleText.Size = new System.Drawing.Size(555, 174);
			this.fileNameStyleText.TabIndex = 16;
			// 
			// tabLineStyle
			// 
			this.tabLineStyle.Controls.Add(this.lineStyleLabel);
			this.tabLineStyle.Controls.Add(this.lineStyleText);
			this.tabLineStyle.Location = new System.Drawing.Point(4, 22);
			this.tabLineStyle.Name = "tabLineStyle";
			this.tabLineStyle.Size = new System.Drawing.Size(571, 204);
			this.tabLineStyle.TabIndex = 2;
			this.tabLineStyle.Text = "Line Style";
			this.tabLineStyle.UseVisualStyleBackColor = true;
			// 
			// lineStyleLabel
			// 
			this.lineStyleLabel.Location = new System.Drawing.Point(8, 8);
			this.lineStyleLabel.Name = "lineStyleLabel";
			this.lineStyleLabel.Size = new System.Drawing.Size(392, 16);
			this.lineStyleLabel.TabIndex = 2;
			this.lineStyleLabel.Text = "Additional CSS rules for each line\'s <p> or <pre> tag:";
			// 
			// lineStyleText
			// 
			this.lineStyleText.AcceptsReturn = true;
			this.lineStyleText.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
						| System.Windows.Forms.AnchorStyles.Left)
						| System.Windows.Forms.AnchorStyles.Right)));
			this.lineStyleText.Location = new System.Drawing.Point(8, 24);
			this.lineStyleText.Multiline = true;
			this.lineStyleText.Name = "lineStyleText";
			this.lineStyleText.ScrollBars = System.Windows.Forms.ScrollBars.Vertical;
			this.lineStyleText.Size = new System.Drawing.Size(555, 174);
			this.lineStyleText.TabIndex = 14;
			// 
			// tabLineNumberStyle
			// 
			this.tabLineNumberStyle.Controls.Add(this.lineNumberStyleLabel);
			this.tabLineNumberStyle.Controls.Add(this.lineNumberStyleText);
			this.tabLineNumberStyle.Location = new System.Drawing.Point(4, 22);
			this.tabLineNumberStyle.Name = "tabLineNumberStyle";
			this.tabLineNumberStyle.Padding = new System.Windows.Forms.Padding(3);
			this.tabLineNumberStyle.Size = new System.Drawing.Size(571, 204);
			this.tabLineNumberStyle.TabIndex = 8;
			this.tabLineNumberStyle.Text = "Line Number Style";
			this.tabLineNumberStyle.UseVisualStyleBackColor = true;
			// 
			// lineNumberStyleLabel
			// 
			this.lineNumberStyleLabel.Location = new System.Drawing.Point(8, 8);
			this.lineNumberStyleLabel.Name = "lineNumberStyleLabel";
			this.lineNumberStyleLabel.Size = new System.Drawing.Size(392, 16);
			this.lineNumberStyleLabel.TabIndex = 16;
			this.lineNumberStyleLabel.Text = "Additional CSS rules for each line number\'s <span> tag:";
			// 
			// lineNumberStyleText
			// 
			this.lineNumberStyleText.AcceptsReturn = true;
			this.lineNumberStyleText.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
						| System.Windows.Forms.AnchorStyles.Left)
						| System.Windows.Forms.AnchorStyles.Right)));
			this.lineNumberStyleText.Location = new System.Drawing.Point(8, 24);
			this.lineNumberStyleText.Multiline = true;
			this.lineNumberStyleText.Name = "lineNumberStyleText";
			this.lineNumberStyleText.ScrollBars = System.Windows.Forms.ScrollBars.Vertical;
			this.lineNumberStyleText.Size = new System.Drawing.Size(555, 174);
			this.lineNumberStyleText.TabIndex = 17;
			// 
			// tabBlockStyle
			// 
			this.tabBlockStyle.Controls.Add(this.blockStyleLabel);
			this.tabBlockStyle.Controls.Add(this.blockStyleText);
			this.tabBlockStyle.Location = new System.Drawing.Point(4, 22);
			this.tabBlockStyle.Name = "tabBlockStyle";
			this.tabBlockStyle.Size = new System.Drawing.Size(571, 204);
			this.tabBlockStyle.TabIndex = 3;
			this.tabBlockStyle.Text = "Block Style";
			this.tabBlockStyle.UseVisualStyleBackColor = true;
			// 
			// blockStyleLabel
			// 
			this.blockStyleLabel.Location = new System.Drawing.Point(8, 8);
			this.blockStyleLabel.Name = "blockStyleLabel";
			this.blockStyleLabel.Size = new System.Drawing.Size(392, 16);
			this.blockStyleLabel.TabIndex = 3;
			this.blockStyleLabel.Text = "Additional CSS rules for each block\'s <span> tag:";
			// 
			// blockStyleText
			// 
			this.blockStyleText.AcceptsReturn = true;
			this.blockStyleText.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
						| System.Windows.Forms.AnchorStyles.Left)
						| System.Windows.Forms.AnchorStyles.Right)));
			this.blockStyleText.Location = new System.Drawing.Point(8, 24);
			this.blockStyleText.Multiline = true;
			this.blockStyleText.Name = "blockStyleText";
			this.blockStyleText.ScrollBars = System.Windows.Forms.ScrollBars.Vertical;
			this.blockStyleText.Size = new System.Drawing.Size(555, 174);
			this.blockStyleText.TabIndex = 15;
			// 
			// tabOutput
			// 
			this.tabOutput.Controls.Add(this.stripLineBreaksCheck);
			this.tabOutput.Controls.Add(this.embedStylesCheck);
			this.tabOutput.Location = new System.Drawing.Point(4, 22);
			this.tabOutput.Name = "tabOutput";
			this.tabOutput.Padding = new System.Windows.Forms.Padding(3);
			this.tabOutput.Size = new System.Drawing.Size(571, 204);
			this.tabOutput.TabIndex = 6;
			this.tabOutput.Text = "Output";
			this.tabOutput.UseVisualStyleBackColor = true;
			// 
			// stripLineBreaksCheck
			// 
			this.stripLineBreaksCheck.BackColor = System.Drawing.SystemColors.Control;
			this.stripLineBreaksCheck.Location = new System.Drawing.Point(8, 8);
			this.stripLineBreaksCheck.Name = "stripLineBreaksCheck";
			this.stripLineBreaksCheck.Size = new System.Drawing.Size(112, 17);
			this.stripLineBreaksCheck.TabIndex = 0;
			this.stripLineBreaksCheck.Text = "Strip line &breaks";
			this.stripLineBreaksCheck.UseVisualStyleBackColor = false;
			// 
			// embedStylesCheck
			// 
			this.embedStylesCheck.BackColor = System.Drawing.SystemColors.Control;
			this.embedStylesCheck.Location = new System.Drawing.Point(8, 32);
			this.embedStylesCheck.Name = "embedStylesCheck";
			this.embedStylesCheck.Size = new System.Drawing.Size(96, 17);
			this.embedStylesCheck.TabIndex = 1;
			this.embedStylesCheck.Text = "&Embed styles";
			this.embedStylesCheck.UseVisualStyleBackColor = false;
			// 
			// tabAddIn
			// 
			this.tabAddIn.Controls.Add(this.restartVirtualMachineAdditionsCheck);
			this.tabAddIn.Controls.Add(this.addSaveNowFileMenuCheck);
			this.tabAddIn.Controls.Add(this.addSaveFileMenuCheck);
			this.tabAddIn.Controls.Add(this.saveScenariosCheck);
			this.tabAddIn.Controls.Add(this.copyNowLabel);
			this.tabAddIn.Controls.Add(this.copyLabel);
			this.tabAddIn.Controls.Add(this.addCopyNowEditMenuCheck);
			this.tabAddIn.Controls.Add(this.addCopyEditMenuCheck);
			this.tabAddIn.Controls.Add(this.addCopyNowContextMenuCheck);
			this.tabAddIn.Controls.Add(this.addCopyContextMenuCheck);
			this.tabAddIn.Location = new System.Drawing.Point(4, 22);
			this.tabAddIn.Name = "tabAddIn";
			this.tabAddIn.Size = new System.Drawing.Size(571, 204);
			this.tabAddIn.TabIndex = 5;
			this.tabAddIn.Text = "Add-In";
			this.tabAddIn.UseVisualStyleBackColor = true;
			// 
			// restartVirtualMachineAdditionsCheck
			// 
			this.restartVirtualMachineAdditionsCheck.AutoSize = true;
			this.restartVirtualMachineAdditionsCheck.Location = new System.Drawing.Point(10, 105);
			this.restartVirtualMachineAdditionsCheck.Name = "restartVirtualMachineAdditionsCheck";
			this.restartVirtualMachineAdditionsCheck.Size = new System.Drawing.Size(308, 17);
			this.restartVirtualMachineAdditionsCheck.TabIndex = 8;
			this.restartVirtualMachineAdditionsCheck.Text = "Restart &Virtual PC virtual machine additions when necessary";
			this.restartVirtualMachineAdditionsCheck.UseVisualStyleBackColor = true;
			// 
			// addSaveNowFileMenuCheck
			// 
			this.addSaveNowFileMenuCheck.BackColor = System.Drawing.SystemColors.Control;
			this.addSaveNowFileMenuCheck.Location = new System.Drawing.Point(10, 74);
			this.addSaveNowFileMenuCheck.Name = "addSaveNowFileMenuCheck";
			this.addSaveNowFileMenuCheck.Size = new System.Drawing.Size(73, 17);
			this.addSaveNowFileMenuCheck.TabIndex = 5;
			this.addSaveNowFileMenuCheck.Text = "File menu";
			this.addSaveNowFileMenuCheck.UseVisualStyleBackColor = false;
			// 
			// addSaveFileMenuCheck
			// 
			this.addSaveFileMenuCheck.BackColor = System.Drawing.SystemColors.Control;
			this.addSaveFileMenuCheck.Location = new System.Drawing.Point(10, 27);
			this.addSaveFileMenuCheck.Name = "addSaveFileMenuCheck";
			this.addSaveFileMenuCheck.Size = new System.Drawing.Size(73, 17);
			this.addSaveFileMenuCheck.TabIndex = 1;
			this.addSaveFileMenuCheck.Text = "File menu";
			this.addSaveFileMenuCheck.UseVisualStyleBackColor = false;
			// 
			// saveScenariosCheck
			// 
			this.saveScenariosCheck.AutoSize = true;
			this.saveScenariosCheck.Location = new System.Drawing.Point(10, 137);
			this.saveScenariosCheck.Name = "saveScenariosCheck";
			this.saveScenariosCheck.Size = new System.Drawing.Size(292, 17);
			this.saveScenariosCheck.TabIndex = 9;
			this.saveScenariosCheck.Text = "Save &scenario files for bug reporting or regression testing";
			this.saveScenariosCheck.UseVisualStyleBackColor = true;
			// 
			// copyNowLabel
			// 
			this.copyNowLabel.Location = new System.Drawing.Point(8, 55);
			this.copyNowLabel.Name = "copyNowLabel";
			this.copyNowLabel.Size = new System.Drawing.Size(400, 16);
			this.copyNowLabel.TabIndex = 4;
			this.copyNowLabel.Text = "Add commands to copy and save without prompting (will not show this dialog):";
			// 
			// copyLabel
			// 
			this.copyLabel.Location = new System.Drawing.Point(8, 8);
			this.copyLabel.Name = "copyLabel";
			this.copyLabel.Size = new System.Drawing.Size(400, 16);
			this.copyLabel.TabIndex = 0;
			this.copyLabel.Text = "Add commands to copy and save with prompting (will show this dialog):";
			// 
			// addCopyNowEditMenuCheck
			// 
			this.addCopyNowEditMenuCheck.BackColor = System.Drawing.SystemColors.Control;
			this.addCopyNowEditMenuCheck.Location = new System.Drawing.Point(89, 74);
			this.addCopyNowEditMenuCheck.Name = "addCopyNowEditMenuCheck";
			this.addCopyNowEditMenuCheck.Size = new System.Drawing.Size(73, 17);
			this.addCopyNowEditMenuCheck.TabIndex = 6;
			this.addCopyNowEditMenuCheck.Text = "Edit menu";
			this.addCopyNowEditMenuCheck.UseVisualStyleBackColor = false;
			// 
			// addCopyEditMenuCheck
			// 
			this.addCopyEditMenuCheck.BackColor = System.Drawing.SystemColors.Control;
			this.addCopyEditMenuCheck.Location = new System.Drawing.Point(89, 27);
			this.addCopyEditMenuCheck.Name = "addCopyEditMenuCheck";
			this.addCopyEditMenuCheck.Size = new System.Drawing.Size(73, 17);
			this.addCopyEditMenuCheck.TabIndex = 2;
			this.addCopyEditMenuCheck.Text = "Edit menu";
			this.addCopyEditMenuCheck.UseVisualStyleBackColor = false;
			// 
			// addCopyNowContextMenuCheck
			// 
			this.addCopyNowContextMenuCheck.BackColor = System.Drawing.SystemColors.Control;
			this.addCopyNowContextMenuCheck.Location = new System.Drawing.Point(168, 74);
			this.addCopyNowContextMenuCheck.Name = "addCopyNowContextMenuCheck";
			this.addCopyNowContextMenuCheck.Size = new System.Drawing.Size(125, 17);
			this.addCopyNowContextMenuCheck.TabIndex = 7;
			this.addCopyNowContextMenuCheck.Text = "Editor context menus";
			this.addCopyNowContextMenuCheck.UseVisualStyleBackColor = false;
			// 
			// addCopyContextMenuCheck
			// 
			this.addCopyContextMenuCheck.BackColor = System.Drawing.SystemColors.Control;
			this.addCopyContextMenuCheck.Location = new System.Drawing.Point(169, 27);
			this.addCopyContextMenuCheck.Name = "addCopyContextMenuCheck";
			this.addCopyContextMenuCheck.Size = new System.Drawing.Size(125, 17);
			this.addCopyContextMenuCheck.TabIndex = 3;
			this.addCopyContextMenuCheck.Text = "Editor context menus";
			this.addCopyContextMenuCheck.UseVisualStyleBackColor = false;
			// 
			// tabAbout
			// 
			this.tabAbout.Controls.Add(this.visitWebSiteLabel);
			this.tabAbout.Controls.Add(this.copyrightLabel);
			this.tabAbout.Controls.Add(this.versionLabel);
			this.tabAbout.Controls.Add(this.licenseText);
			this.tabAbout.Location = new System.Drawing.Point(4, 22);
			this.tabAbout.Name = "tabAbout";
			this.tabAbout.Size = new System.Drawing.Size(571, 204);
			this.tabAbout.TabIndex = 4;
			this.tabAbout.Text = "About";
			this.tabAbout.UseVisualStyleBackColor = true;
			// 
			// visitWebSiteLabel
			// 
			this.visitWebSiteLabel.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)
						| System.Windows.Forms.AnchorStyles.Right)));
			this.visitWebSiteLabel.Location = new System.Drawing.Point(8, 182);
			this.visitWebSiteLabel.Name = "visitWebSiteLabel";
			this.visitWebSiteLabel.Size = new System.Drawing.Size(344, 16);
			this.visitWebSiteLabel.TabIndex = 2;
			this.visitWebSiteLabel.TabStop = true;
			this.visitWebSiteLabel.Text = "Visit the CopySourceAsHtml web site.";
			this.visitWebSiteLabel.LinkClicked += new System.Windows.Forms.LinkLabelLinkClickedEventHandler(this.visitWebSiteLabel_LinkClicked);
			// 
			// copyrightLabel
			// 
			this.copyrightLabel.Location = new System.Drawing.Point(8, 32);
			this.copyrightLabel.Name = "copyrightLabel";
			this.copyrightLabel.Size = new System.Drawing.Size(400, 16);
			this.copyrightLabel.TabIndex = 8;
			this.copyrightLabel.Text = "Copyright  2008 J.T. Leigh && Associates Inc. All rights reserved.";
			// 
			// versionLabel
			// 
			this.versionLabel.Location = new System.Drawing.Point(8, 8);
			this.versionLabel.Name = "versionLabel";
			this.versionLabel.Size = new System.Drawing.Size(400, 16);
			this.versionLabel.TabIndex = 6;
			this.versionLabel.Text = "CopySourceAsHtml version 3.1";
			// 
			// licenseText
			// 
			this.licenseText.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
						| System.Windows.Forms.AnchorStyles.Left)
						| System.Windows.Forms.AnchorStyles.Right)));
			this.licenseText.Location = new System.Drawing.Point(8, 56);
			this.licenseText.Multiline = true;
			this.licenseText.Name = "licenseText";
			this.licenseText.ReadOnly = true;
			this.licenseText.ScrollBars = System.Windows.Forms.ScrollBars.Vertical;
			this.licenseText.Size = new System.Drawing.Size(555, 118);
			this.licenseText.TabIndex = 1;
			this.licenseText.Text = resources.GetString("licenseText.Text");
			// 
			// previewCopiedHtmlLabel
			// 
			this.previewCopiedHtmlLabel.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
			this.previewCopiedHtmlLabel.AutoSize = true;
			this.previewCopiedHtmlLabel.Location = new System.Drawing.Point(12, 249);
			this.previewCopiedHtmlLabel.Name = "previewCopiedHtmlLabel";
			this.previewCopiedHtmlLabel.Size = new System.Drawing.Size(134, 13);
			this.previewCopiedHtmlLabel.TabIndex = 3;
			this.previewCopiedHtmlLabel.TabStop = true;
			this.previewCopiedHtmlLabel.Text = "Preview the copied HTML.";
			this.previewCopiedHtmlLabel.Visible = false;
			this.previewCopiedHtmlLabel.LinkClicked += new System.Windows.Forms.LinkLabelLinkClickedEventHandler(this.previewCopiedHtmlLabel_LinkClicked);
			// 
			// CopierPreferencesDialog
			// 
			this.AcceptButton = this.okButton;
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.CancelButton = this.cancelButton;
			this.ClientSize = new System.Drawing.Size(597, 277);
			this.ControlBox = false;
			this.Controls.Add(this.previewCopiedHtmlLabel);
			this.Controls.Add(this.tabs);
			this.Controls.Add(this.cancelButton);
			this.Controls.Add(this.okButton);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.Name = "CopierPreferencesDialog";
			this.ShowInTaskbar = false;
			this.SizeGripStyle = System.Windows.Forms.SizeGripStyle.Hide;
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
			this.Text = "Copy As HTML";
			this.tabs.ResumeLayout(false);
			this.tabGeneral.ResumeLayout(false);
			this.tabGeneral.PerformLayout();
			((System.ComponentModel.ISupportInitialize)(this.adjustmentUpDown)).EndInit();
			this.tabFileStyle.ResumeLayout(false);
			this.tabFileStyle.PerformLayout();
			this.tabFileNameStyle.ResumeLayout(false);
			this.tabFileNameStyle.PerformLayout();
			this.tabLineStyle.ResumeLayout(false);
			this.tabLineStyle.PerformLayout();
			this.tabLineNumberStyle.ResumeLayout(false);
			this.tabLineNumberStyle.PerformLayout();
			this.tabBlockStyle.ResumeLayout(false);
			this.tabBlockStyle.PerformLayout();
			this.tabOutput.ResumeLayout(false);
			this.tabAddIn.ResumeLayout(false);
			this.tabAddIn.PerformLayout();
			this.tabAbout.ResumeLayout(false);
			this.tabAbout.PerformLayout();
			this.ResumeLayout(false);
			this.PerformLayout();

        }
        #endregion

        private void okButton_Click(object sender, EventArgs args)
        {

            int numberLinesFrom = 0;
            int tabSize = -1;
            string fontList = null;
            int fontSize = 0;
            string fileStyle = null;
			string fileNameStyle = null;
            string lineStyle = null;
			string lineNumberStyle = null;
			string blockStyle = null;

            if (numberLinesCheck.Checked)
            {
				if (!Int32.TryParse(numberLinesFromText.Text, NumberStyles.Integer, CultureInfo.CurrentUICulture, out numberLinesFrom))
				{
					numberLinesFrom = 0;
				}
				if (numberLinesFrom < 1)
				{
					MessageBox.Show(Resources.InvalidLineNumberMessage, Resources.InvalidLineNumberCaption, MessageBoxButtons.OK, MessageBoxIcon.Error);
					numberLinesFromText.Focus();
					return;
				}
            }
            if (overrideTabSizeCheck.Checked)
            {
				if (!Int32.TryParse(tabSizeText.Text, NumberStyles.Integer, CultureInfo.CurrentUICulture, out tabSize))
				{
					tabSize = -1;
				}
                if (tabSize < 0)
                {
                    MessageBox.Show(Resources.InvalidTabSizeMessage, Resources.InvalidTabSizeCaption, MessageBoxButtons.OK, MessageBoxIcon.Error);
                    tabSizeText.Focus();
                    return;
                }
            }
            if (overrideFontListCheck.Checked)
            {
                fontList = GetCleanFontList(fontListText.Text);
                if (fontList == null)
                {
                    MessageBox.Show(Resources.InvalidFontListMessage, Resources.InvalidFontListCaption, MessageBoxButtons.OK, MessageBoxIcon.Error);
                    fontListText.Focus();
                    return;
                }
            }
            if (overrideFontSizeCheck.Checked)
            {
				if (!Int32.TryParse(fontSizeText.Text, NumberStyles.Integer, CultureInfo.CurrentUICulture, out fontSize))
				{
                    fontSize = 0;
                }
                if (fontSize < 1)
                {
                    MessageBox.Show(Resources.InvalidFontSizeMessage, Resources.InvalidFontSizeCaption, MessageBoxButtons.OK, MessageBoxIcon.Error);
                    fontSizeText.Focus();
                    return;
                }
            }
            fileStyle = GetCompactStyleList(fileStyleText.Text);
			fileNameStyle = GetCompactStyleList(fileNameStyleText.Text);
            lineStyle = GetCompactStyleList(lineStyleText.Text);
			lineNumberStyle = GetCompactStyleList(lineNumberStyleText.Text);
            blockStyle = GetCompactStyleList(blockStyleText.Text);

            // ...

            Settings.Default.NumberLines = numberLinesCheck.Checked;
            if (numberLinesCheck.Checked)
            {
                Settings.Default.NumberLinesFrom = numberLinesFrom;
            }
            Settings.Default.WrapWords = wrapWordsCheck.Checked;
            Settings.Default.EmbedStyles = embedStylesCheck.Checked;
            Settings.Default.StripLineBreaks = stripLineBreaksCheck.Checked;
            Settings.Default.RemoveIndentation = removeIndentationCheck.Checked;
            Settings.Default.OverrideTabSize = overrideTabSizeCheck.Checked;
            if (overrideTabSizeCheck.Checked)
            {
                Settings.Default.TabSize = tabSize;
            }
            Settings.Default.OverrideFontList = overrideFontListCheck.Checked;
            if (overrideFontListCheck.Checked)
            {
                Settings.Default.FontList = fontList;
            }
            Settings.Default.OverrideFontSize = overrideFontSizeCheck.Checked;
            if (overrideFontSizeCheck.Checked)
            {
                Settings.Default.FontSize = fontSize;
            }
			Settings.Default.AlternateBackgroundColors = alternateBackgroundColorsCheck.Checked;
			if (alternateBackgroundColorsCheck.Checked)
			{
				Settings.Default.AlternateBackgroundColorAdjustment = (double)(adjustmentUpDown.Value / 100);
			}
			Settings.Default.CopyFileName = copyFileNameCheck.Checked;
			// TODO: copyFileNamePath...
			Settings.Default.FileStyle = fileStyle;
			Settings.Default.FileNameStyle = fileNameStyle;
            Settings.Default.LineStyle = lineStyle;
			Settings.Default.LineNumberStyle = lineNumberStyle;
            Settings.Default.BlockStyle = blockStyle;
			Settings.Default.AddSaveFileMenu = addSaveFileMenuCheck.Checked;
			Settings.Default.AddCopyEditMenu = addCopyEditMenuCheck.Checked;
			Settings.Default.AddCopyContextMenu = addCopyContextMenuCheck.Checked;
			Settings.Default.AddSaveNowFileMenu = addSaveNowFileMenuCheck.Checked;
			Settings.Default.AddCopyNowEditMenu = addCopyNowEditMenuCheck.Checked;
			Settings.Default.AddCopyNowContextMenu = addCopyNowContextMenuCheck.Checked;
			Settings.Default.SaveScenarios = saveScenariosCheck.Checked;
			Settings.Default.RestartVirtualMachineAdditions = restartVirtualMachineAdditionsCheck.Checked;
            Settings.Default.Save();

            DialogResult = DialogResult.OK;
            Close();

        }

        private void numberLinesCheck_CheckedChanged(object sender, EventArgs args)
        {
            numberLinesFromText.Enabled = numberLinesCheck.Checked;
        }

        private void overrideTabSizeCheck_CheckedChanged(object sender, EventArgs args)
        {
            tabSizeText.Enabled = overrideTabSizeCheck.Checked;
        }

        private void overrideFontListCheck_CheckedChanged(object sender, EventArgs args)
        {
            fontListText.Enabled = overrideFontListCheck.Checked;
        }

        private void overrideFontSizeCheck_CheckedChanged(object sender, EventArgs args)
        {
            fontSizeText.Enabled = overrideFontSizeCheck.Checked;
        }

        private void visitWebSiteLabel_LinkClicked(object sender, LinkLabelLinkClickedEventArgs args)
        {
            Process.Start((string)args.Link.LinkData);
        }

        internal static string GetCleanFontList(string dirtyFontList)
        {

            string[] dirtyFonts;
            StringBuilder cleanFontList;
            string cleanFont;

            if (dirtyFontList == null)
            {
                return null;
            }
            dirtyFonts = dirtyFontList.Split(',');
            cleanFontList = new StringBuilder(dirtyFontList.Length);
            foreach (string dirtyFont in dirtyFonts)
            {
                cleanFont = dirtyFont.Trim();
                if (cleanFont.Length > 0)
                {
                    if (cleanFontList.Length > 0)
                    {
                        cleanFontList.Append(", ");
                    }
                    cleanFontList.Append(cleanFont);
                }
            }
            return cleanFontList.ToString();

        }

        internal static string GetCompactStyleList(string friendlyStyleList)
        {

            string[] friendlyStyles;
            StringBuilder compactStyleList;
            string compactStyle;

            if (friendlyStyleList == null)
            {
                return null;
            }
            friendlyStyleList = friendlyStyleList.Replace('\r', ' ');
            friendlyStyleList = friendlyStyleList.Replace('\n', ' ');
            friendlyStyles = friendlyStyleList.Split(';');
            compactStyleList = new StringBuilder(friendlyStyleList.Length);
            foreach (string friendlyStyle in friendlyStyles)
            {
                compactStyle = friendlyStyle.Trim();
                if (compactStyle.Length > 0)
                {
                    if (compactStyleList.Length > 0)
                    {
                        compactStyleList.Append(' ');
                    }
                    compactStyleList.Append(compactStyle);
                    compactStyleList.Append(';');
                }
            }
            return compactStyleList.ToString();

        }

        internal static string GetFriendlyStyleList(string compactStyleList)
        {

            string[] compactStyles;
            StringBuilder friendlyStyleList;
            string friendlyStyle;

            if (compactStyleList == null)
            {
                return null;
            }
            compactStyleList = compactStyleList.Replace('\r', ' ');
            compactStyleList = compactStyleList.Replace('\n', ' ');
            compactStyles = compactStyleList.Split(';');
            friendlyStyleList = new StringBuilder(compactStyleList.Length);
            foreach (string compactStyle in compactStyles)
            {
                friendlyStyle = compactStyle.Trim();
                if (friendlyStyle.Length > 0)
                {
                    friendlyStyleList.Append(friendlyStyle);
                    friendlyStyleList.Append(";\r\n");
                }
            }
            return friendlyStyleList.ToString();

		}

		private void alternateBackgroundColorsCheck_CheckedChanged(object sender, EventArgs e)
		{
			adjustmentUpDown.Enabled = alternateBackgroundColorsCheck.Checked;
		}

		private void copyFileNameCheck_CheckedChanged(object sender, EventArgs e)
		{
			pathCombo.Enabled = copyFileNameCheck.Checked;
		}

		private void previewCopiedHtmlLabel_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
		{
			// TODO
		}

	}
}
